==> github-issues-to-hexo-1.0.3.tgz: package/Readme.md <==
# Github issues to hexo

## Installation
Available from `npm`

```shell
npm install github-issues-to-blog -g
```

## Usage

Get help:

```shell
github-issues-to-hexo --help
```

Convert your blog:

```shell
cd /path/to/hexo-blog-source/
github-issues-to-hexo -u github-username -u github-repo
```

Using template:
```shell
cd /path/to/hexo-blog-source/

# init template
github-issues-to-hexo init your-template.md

# edit your template
vim your-template.md

# convert your blog
github-issues-to-hexo -u github-username -u github-repo -t your-template.md
```

## License

The MIT License (MIT)

Copyright (c) 2017 Zhipei Xu

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

==> github-issues-to-hexo-1.0.4.tgz: package/Readme.md <==
# Github issues to hexo

## Installation
Available from `npm`

```shell
npm install github-issues-to-blog -g
```

## Usage

Get help:

```shell
github-issues-to-hexo --help
```

Convert your blog:

```shell
cd /path/to/hexo-blog-source/
github-issues-to-hexo -u github-username -u github-repo --since 2017-09-01
```

Using template:
```shell
cd /path/to/hexo-blog-source/

# init template
github-issues-to-hexo init your-template.md

# edit your template
vim your-template.md

# convert your blog
github-issues-to-hexo -u github-username -u github-repo -t your-template.md
```

## License

The MIT License (MIT)

Copyright (c) 2017 Zhipei Xu

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
